@@ -1,5 +1,5 @@
 package Crypt::Bcrypt::Easy;
-$Crypt::Bcrypt::Easy::VERSION = '2.008002';
+$Crypt::Bcrypt::Easy::VERSION = '2.009001';
 use Carp;
 use strictures 2;
 use App::bmkpasswd 'mkpasswd', 'passwdcmp', 'mkpasswd_forked';
@@ -10,34 +10,36 @@ use parent 'Exporter::Tiny';
 our @EXPORT = 'bcrypt';
 sub bcrypt {  Crypt::Bcrypt::Easy->new(@_)  }
 
+sub DEFAULT_COST () { '08' }
+
 =pod
 
-=for Pod::Coverage new
+=for Pod::Coverage new DEFAULT_COST
 
 =cut
 
 sub new {
   my ($cls, %params) = @_;
-  my $cost = $params{cost} || '08';
+  my $cost = $params{cost} || DEFAULT_COST;
   mkpasswd_forked if $params{reset_seed};
   bless \$cost, blessed($cls) || $cls
 }
 
-sub cost { ${ $_[0] } }
+sub cost { 
+  my ($self) = @_;
+  blessed $self ? $$self : DEFAULT_COST
+}
 
 sub compare {
   my ($self, %params) = @_;
-
   unless (defined $params{text} && defined $params{crypt}) {
     confess "Expected 'text =>' and 'crypt =>' params"
   }
-
   passwdcmp $params{text} => $params{crypt}
 }
 
 sub crypt {
   my $self = shift;
-
   my %params;
 
   if (@_ == 1) {
@@ -73,22 +75,27 @@ Crypt::Bcrypt::Easy - Simple interface to bcrypted passwords
   my $passwd = bcrypt->crypt( $plain );
 
   # Generate passwords with non-default options:
-  my $passwd = bcrypt->crypt( text => $plain, cost => 8 );
+  my $passwd = bcrypt->crypt( text => $plain, cost => 10 );
 
   # Compare passwords:
   if (bcrypt->compare( text => $plain, crypt => $passwd )) {
     # Successful match
   }
 
-  # Generate passwords using a different default workcost:
+  # Spawn a new instance that will generate passwords using a different
+  # default workcost:
   my $bc = bcrypt( cost => 10 );
-  my $crypted = $bc->crypt( $plain );
+  my $passwd = $bc->crypt( $plain );
+
+  # Without imported constructor:
+  use Crypt::Bcrypt::Easy ();
+  my $passwd = Crypt::Bcrypt::Easy->crypt( text => $plain, cost => 10 )
 
 =head1 DESCRIPTION
 
 This module provides an easy interface to creating and comparing bcrypt-hashed
 passwords via L<App::bmkpasswd>'s exported helpers (which were created to
-power L<bmkpasswd> and are a bit awkward to use directly).
+power C<bmkpasswd(1)> and are a bit awkward to use directly).
 
 This POD briefly covers usage of this interface; see L<App::bmkpasswd> for
 more details on bcrypt, internals, and documentation regarding the more
